@@ -2,7 +2,7 @@ package Mojolicious::Plugin::INIConfig::Extended;
 use Mojo::Base 'Mojolicious::Plugin::INIConfig';
 use Config::Tiny;
 use File::Spec::Functions 'file_name_is_absolute';
-use Mojo::Util qw/encode decode slurp/;
+use Mojo::Util qw/encode decode/;
 use Data::Dumper;
 
 our $VERSION = '0.05';
